pub fn derive_status_to_nautilus(
status: DeriveOrderStatus,
filled_qty: Decimal,
quantity: Decimal,
) -> OrderStatusExpand description
Maps a Derive order status to the Nautilus equivalent, given the current filled quantity.
pub fn derive_status_to_nautilus(
status: DeriveOrderStatus,
filled_qty: Decimal,
quantity: Decimal,
) -> OrderStatusMaps a Derive order status to the Nautilus equivalent, given the current filled quantity.